@@ -3,35 +3,52 @@ from highdicom import color
 from highdicom import ko
 from highdicom import legacy
 from highdicom import pm
+from highdicom import pr
 from highdicom import sc
 from highdicom import seg
 from highdicom import sr
 from highdicom.base import SOPClass
 from highdicom.content import (
     AlgorithmIdentificationSequence,
+    ContentCreatorIdentificationCodeSequence,
     IssuerOfIdentifier,
+    LUT,
+    ModalityLUT,
+    ModalityLUTTransformation,
+    PaletteColorLUT,
+    PaletteColorLUTTransformation,
     PixelMeasuresSequence,
-    PlanePositionSequence,
     PlaneOrientationSequence,
+    PlanePositionSequence,
+    PresentationLUT,
+    PresentationLUTTransformation,
+    ReferencedImageSequence,
+    SegmentedPaletteColorLUT,
     SpecimenCollection,
     SpecimenDescription,
     SpecimenPreparationStep,
+    SpecimenProcessing,
     SpecimenSampling,
     SpecimenStaining,
+    VOILUT,
+    VOILUTTransformation,
 )
 from highdicom.enum import (
+    AnatomicalOrientationTypeValues,
     CoordinateSystemNames,
     ContentQualificationValues,
     DimensionOrganizationTypeValues,
+    LateralityValues,
     PatientSexValues,
     PhotometricInterpretationValues,
-    PlanarConfigurationValues,
     PixelRepresentationValues,
-    LateralityValues,
-    AnatomicalOrientationTypeValues,
+    PlanarConfigurationValues,
     PatientOrientationValuesBiped,
     PatientOrientationValuesQuadruped,
-    UniversalEntityIDTypeValues
+    PresentationLUTShapeValues,
+    RescaleTypeValues,
+    UniversalEntityIDTypeValues,
+    VOILUTFunctionValues,
 )
 from highdicom import frame
 from highdicom import io
@@ -43,11 +60,17 @@ from highdicom.version import __version__
 __all__ = [
     'AlgorithmIdentificationSequence',
     'AnatomicalOrientationTypeValues',
+    'ContentCreatorIdentificationCodeSequence',
     'ContentQualificationValues',
     'CoordinateSystemNames',
     'DimensionOrganizationTypeValues',
     'IssuerOfIdentifier',
     'LateralityValues',
+    'LUT',
+    'ModalityLUT',
+    'ModalityLUTTransformation',
+    'PaletteColorLUT',
+    'PaletteColorLUTTransformation',
     'PatientOrientationValuesBiped',
     'PatientOrientationValuesQuadruped',
     'PatientSexValues',
@@ -57,14 +80,24 @@ __all__ = [
     'PlanarConfigurationValues',
     'PlaneOrientationSequence',
     'PlanePositionSequence',
+    'PresentationLUT',
+    'PresentationLUTShapeValues',
+    'PresentationLUTTransformation',
+    'ReferencedImageSequence',
+    'RescaleTypeValues',
+    'SegmentedPaletteColorLUT',
     'SpecimenCollection',
     'SpecimenDescription',
     'SpecimenPreparationStep',
+    'SpecimenProcessing',
     'SpecimenSampling',
     'SpecimenStaining',
     'SOPClass',
     'UID',
     'UniversalEntityIDTypeValues',
+    'VOILUT',
+    'VOILUTFunctionValues',
+    'VOILUTTransformation',
     'ann',
     'color',
     'frame',
@@ -72,6 +105,7 @@ __all__ = [
     'ko',
     'legacy',
     'pm',
+    'pr',
     'sc',
     'seg',
     'spatial',
