@@ -68,7 +68,7 @@ class MicroscopyBulkSimpleAnnotations(SOPClass):
             measurements)
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -122,7 +122,6 @@ class MicroscopyBulkSimpleAnnotations(SOPClass):
             sop_instance_uid=sop_instance_uid,
             instance_number=instance_number,
             sop_class_uid='1.2.840.10008.5.1.4.1.1.91.1',
-            manufacturer=manufacturer,
             modality='ANN',
             transfer_syntax_uid=transfer_syntax_uid,
             patient_id=src_img.PatientID,
@@ -136,6 +135,10 @@ class MicroscopyBulkSimpleAnnotations(SOPClass):
             referring_physician_name=getattr(
                 src_img, 'ReferringPhysicianName', None
             ),
+            manufacturer=manufacturer,
+            manufacturer_model_name=manufacturer_model_name,
+            device_serial_number=device_serial_number,
+            software_versions=software_versions,
             **kwargs
         )
         self.copy_specimen_information(src_img)
@@ -175,11 +178,6 @@ class MicroscopyBulkSimpleAnnotations(SOPClass):
                 'value.'
             )
 
-        # (Enhanced) General Equipment
-        self.DeviceSerialNumber = device_serial_number
-        self.ManufacturerModelName = manufacturer_model_name
-        self.SoftwareVersions = software_versions
-
         # Common Instance Reference
         self.ReferencedImageSequence: List[Dataset] = []
         referenced_series: Dict[str, List[Dataset]] = defaultdict(list)
@@ -407,7 +405,8 @@ class MicroscopyBulkSimpleAnnotations(SOPClass):
             )
         if dataset.SOPClassUID != '1.2.840.10008.5.1.4.1.1.91.1':
             raise ValueError(
-                'Dataset is not a Microscopy Bulk Simple Annotation.'
+                'Dataset is not a Microscopy Bulk Simple Annotations '
+                'instance.'
             )
         _check_little_endian(dataset)
         ann = deepcopy(dataset)
