@@ -436,7 +436,7 @@ class LegacyConvertedEnhancedMRImage(SOPClass):
             be converted
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -529,7 +529,7 @@ class LegacyConvertedEnhancedCTImage(SOPClass):
             be converted
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -608,7 +608,7 @@ class LegacyConvertedEnhancedPETImage(SOPClass):
             be converted
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
