@@ -785,8 +785,8 @@ def map_pixel_into_coordinate_system(
 
     Parameters
     ----------
-    index: Sequence[float]
-        (column, row) zero-based index at pixel resolution in the range
+    index: Sequence[int]
+        Zero-based (column, row) index at pixel resolution in the range
         [0, Columns - 1] and [0, Rows - 1], respectively.
     image_position: Sequence[float]
         Position of the slice (image or frame) in the frame of reference, i.e.,
